# This file was automatically generated by Dist::Zilla::Plugin::Test::TidyAll v$VERSION

use Test::More 0.88;
BEGIN {
    if ( $] < 5.010 ) {
        plan skip_all => 'This test requires Perl version 5.010';
    }
}
use Test::Code::TidyAll 0.24;

tidyall_ok(
     verbose => ( exists $ENV{TEST_TIDYALL_VERBOSE} ? $ENV{TEST_TIDYALL_VERBOSE} : 1 ),
     jobs => ( exists $ENV{TEST_TIDYALL_JOBS} ? $ENV{TEST_TIDYALL_JOBS} : 4 ),
);

done_testing;
