use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007004
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib ) );
__DATA__
Alders
Alders'
Data
Dave
Eilam
Eilam's
Greg
Hannyaharamitu
IEEE
IEEE754
Inc
MAXMIND
MAXMIND's
Makamaka
MaxMind
MaxMind's
Oschwald
Oschwald's
PayPal
Rolsky
Rolsky's
autarch
drolsky
goschwald
lib
